@@ -2,7 +2,7 @@ import logging
 import random
 import click
 import time
-from pequod_cli.console import print_table, action, ok
+from pequod_cli.console import print_table, action, ok, print_permissions
 import requests
 from pequod_cli.model import ApplicationSpec
 from pequod_cli.utils import AliasedGroup, generate_random_name
@@ -153,4 +153,13 @@ def stop(ctx, instance_name):
                 'node_name': instance_data['node_name'],
                 }], 'allow_partial_commit': False}
         ctx.controller.put('/scheduler', data=data)
-        ok()
\ No newline at end of file
+        ok()
+
+
+@controller.command()
+@click.pass_obj
+def permissions(ctx):
+    """
+    List all permissions
+    """
+    print_permissions(ctx.controller.permissions())
\ No newline at end of file
