@@ -1,5 +1,5 @@
 import click
-from pequod_cli.console import print_table
+from pequod_cli.console import print_table, print_permissions
 from pequod_cli.utils import AliasedGroup
 
 
@@ -26,3 +26,12 @@ def trackers(ctx):
             rows.append({'url': tracker})
 
     print_table(COLS, rows)
+
+
+@replicator.command()
+@click.pass_obj
+def permissions(ctx):
+    """
+    List all permissions
+    """
+    print_permissions(ctx.replicator.permissions())
\ No newline at end of file
